跳到主要内容

AVAppToDevMessageType

搜索

枚举 AVAppToDevMessageType 

源代码
#[repr(i32)]
pub enum AVAppToDevMessageType { AV_APP_TO_DEV_NONE = 1_313_820_229, AV_APP_TO_DEV_WINDOW_SIZE = 1_195_724_621, AV_APP_TO_DEV_WINDOW_REPAINT = 1_380_274_241, AV_APP_TO_DEV_PAUSE = 1_346_458_912, AV_APP_TO_DEV_PLAY = 1_347_174_745, AV_APP_TO_DEV_TOGGLE_PAUSE = 1_346_458_964, AV_APP_TO_DEV_SET_VOLUME = 1_398_165_324, AV_APP_TO_DEV_MUTE = 541_939_028, AV_APP_TO_DEV_UNMUTE = 1_431_131_476, AV_APP_TO_DEV_TOGGLE_MUTE = 1_414_354_260, AV_APP_TO_DEV_GET_VOLUME = 1_196_838_732, AV_APP_TO_DEV_GET_MUTE = 1_196_250_452, }
展开描述

Message types used by avdevice_app_to_dev_control_message().

Variants



AV_APP_TO_DEV_NONE = 1_313_820_229

Dummy message.



AV_APP_TO_DEV_WINDOW_SIZE = 1_195_724_621

Window size change message.

Message is sent to the device every time the application changes the size of the window device renders to. Message should also be sent right after window is created.

data: AVDeviceRect: new window size.



AV_APP_TO_DEV_WINDOW_REPAINT = 1_380_274_241

Repaint request message.

Message is sent to the device when window has to be repainted.

data: AVDeviceRect: area required to be repainted. NULL: whole area is required to be repainted.



AV_APP_TO_DEV_PAUSE = 1_346_458_912

Request pause/play.

Application requests pause/unpause playback. Mostly usable with devices that have internal buffer. By default devices are not paused.

data: NULL



AV_APP_TO_DEV_PLAY = 1_347_174_745

Request pause/play.

Application requests pause/unpause playback. Mostly usable with devices that have internal buffer. By default devices are not paused.

data: NULL



AV_APP_TO_DEV_TOGGLE_PAUSE = 1_346_458_964

Request pause/play.

Application requests pause/unpause playback. Mostly usable with devices that have internal buffer. By default devices are not paused.

data: NULL



AV_APP_TO_DEV_SET_VOLUME = 1_398_165_324

Volume control message.

Set volume level. It may be device-dependent if volume is changed per stream or system wide. Per stream volume change is expected when possible.

data: double: new volume with range of 0.0 - 1.0.



AV_APP_TO_DEV_MUTE = 541_939_028

Mute control messages.

Change mute state. It may be device-dependent if mute status is changed per stream or system wide. Per stream mute status change is expected when possible.

data: NULL.



AV_APP_TO_DEV_UNMUTE = 1_431_131_476

Mute control messages.

Change mute state. It may be device-dependent if mute status is changed per stream or system wide. Per stream mute status change is expected when possible.

data: NULL.



AV_APP_TO_DEV_TOGGLE_MUTE = 1_414_354_260

Mute control messages.

Change mute state. It may be device-dependent if mute status is changed per stream or system wide. Per stream mute status change is expected when possible.

data: NULL.



AV_APP_TO_DEV_GET_VOLUME = 1_196_838_732

Get volume/mute messages.

Force the device to send AV_DEV_TO_APP_VOLUME_LEVEL_CHANGED or AV_DEV_TO_APP_MUTE_STATE_CHANGED command respectively.

data: NULL.



AV_APP_TO_DEV_GET_MUTE = 1_196_250_452

Get volume/mute messages.

Force the device to send AV_DEV_TO_APP_VOLUME_LEVEL_CHANGED or AV_DEV_TO_APP_MUTE_STATE_CHANGED command respectively.

data: NULL.

trait 实现

源代码

impl Clone for AVAppToDevMessageType

源代码

fn clone(&self) -> AVAppToDevMessageType

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVAppToDevMessageType

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Hash for AVAppToDevMessageType

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl PartialEq for AVAppToDevMessageType

源代码

fn eq(&self, other: &AVAppToDevMessageType) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVAppToDevMessageType

源代码

impl Eq for AVAppToDevMessageType

源代码

impl StructuralPartialEq for AVAppToDevMessageType

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。