跳到主要内容

AVCodecConfig

搜索

枚举 AVCodecConfig 

源代码
#[repr(i32)]
pub enum AVCodecConfig { AV_CODEC_CONFIG_PIX_FORMAT = 0, AV_CODEC_CONFIG_FRAME_RATE = 1, AV_CODEC_CONFIG_SAMPLE_RATE = 2, AV_CODEC_CONFIG_SAMPLE_FORMAT = 3, AV_CODEC_CONFIG_CHANNEL_LAYOUT = 4, AV_CODEC_CONFIG_COLOR_RANGE = 5, AV_CODEC_CONFIG_COLOR_SPACE = 6, AV_CODEC_CONFIG_ALPHA_MODE = 7, }

Variants



AV_CODEC_CONFIG_PIX_FORMAT = 0

< AVPixelFormat, terminated by AV_PIX_FMT_NONE



AV_CODEC_CONFIG_FRAME_RATE = 1

< AVRational, terminated by {0, 0}



AV_CODEC_CONFIG_SAMPLE_RATE = 2

< int, terminated by 0



AV_CODEC_CONFIG_SAMPLE_FORMAT = 3

< AVSampleFormat, terminated by AV_SAMPLE_FMT_NONE



AV_CODEC_CONFIG_CHANNEL_LAYOUT = 4

< AVChannelLayout, terminated by {0}



AV_CODEC_CONFIG_COLOR_RANGE = 5

< AVColorRange, terminated by AVCOL_RANGE_UNSPECIFIED



AV_CODEC_CONFIG_COLOR_SPACE = 6

< AVColorSpace, terminated by AVCOL_SPC_UNSPECIFIED



AV_CODEC_CONFIG_ALPHA_MODE = 7

< AVAlphaMode, terminated by AVALPHA_MODE_UNSPECIFIED

trait 实现

源代码

impl Clone for AVCodecConfig

源代码

fn clone(&self) -> AVCodecConfig

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVCodecConfig

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Hash for AVCodecConfig

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl PartialEq for AVCodecConfig

源代码

fn eq(&self, other: &AVCodecConfig) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVCodecConfig

源代码

impl Eq for AVCodecConfig

源代码

impl StructuralPartialEq for AVCodecConfig

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。