跳到主要内容

AVColorSpace

搜索

枚举 AVColorSpace 

源代码
#[repr(i32)]
pub enum AVColorSpace {
Show 19 variants AVCOL_SPC_RGB = 0, AVCOL_SPC_BT709 = 1, AVCOL_SPC_UNSPECIFIED = 2, AVCOL_SPC_RESERVED = 3, AVCOL_SPC_FCC = 4, AVCOL_SPC_BT470BG = 5, AVCOL_SPC_SMPTE170M = 6, AVCOL_SPC_SMPTE240M = 7, AVCOL_SPC_YCGCO = 8, AVCOL_SPC_BT2020_NCL = 9, AVCOL_SPC_BT2020_CL = 10, AVCOL_SPC_SMPTE2085 = 11, AVCOL_SPC_CHROMA_DERIVED_NCL = 12, AVCOL_SPC_CHROMA_DERIVED_CL = 13, AVCOL_SPC_ICTCP = 14, AVCOL_SPC_IPT_C2 = 15, AVCOL_SPC_YCGCO_RE = 16, AVCOL_SPC_YCGCO_RO = 17, AVCOL_SPC_NB = 18,
}
展开描述

YUV colorspace type. These values match the ones defined by ISO/IEC 23091-2_2019 subclause 8.3.

Variants



AVCOL_SPC_RGB = 0

< order of coefficients is actually GBR, also IEC 61966-2-1 (sRGB), YZX and ST 428-1



AVCOL_SPC_BT709 = 1

< also ITU-R BT1361 / IEC 61966-2-4 xvYCC709 / derived in SMPTE RP 177 Annex B



AVCOL_SPC_UNSPECIFIED = 2



AVCOL_SPC_RESERVED = 3

< reserved for future use by ITU-T and ISO/IEC just like 15-255 are



AVCOL_SPC_FCC = 4

< FCC Title 47 Code of Federal Regulations 73.682 (a)(20)



AVCOL_SPC_BT470BG = 5

< also ITU-R BT601-6 625 / ITU-R BT1358 625 / ITU-R BT1700 625 PAL & SECAM / IEC 61966-2-4 xvYCC601



AVCOL_SPC_SMPTE170M = 6

< also ITU-R BT601-6 525 / ITU-R BT1358 525 / ITU-R BT1700 NTSC / functionally identical to above



AVCOL_SPC_SMPTE240M = 7

< derived from 170M primaries and D65 white point, 170M is derived from BT470 System M’s primaries



AVCOL_SPC_YCGCO = 8

< used by Dirac / VC-2 and H.264 FRext, see ITU-T SG16



AVCOL_SPC_BT2020_NCL = 9

< ITU-R BT2020 non-constant luminance system



AVCOL_SPC_BT2020_CL = 10

< ITU-R BT2020 constant luminance system



AVCOL_SPC_SMPTE2085 = 11

< SMPTE 2085, Y’D’zD’x



AVCOL_SPC_CHROMA_DERIVED_NCL = 12

< Chromaticity-derived non-constant luminance system



AVCOL_SPC_CHROMA_DERIVED_CL = 13

< Chromaticity-derived constant luminance system



AVCOL_SPC_ICTCP = 14

< ITU-R BT.2100-0, ICtCp



AVCOL_SPC_IPT_C2 = 15

< SMPTE ST 2128, IPT-C2



AVCOL_SPC_YCGCO_RE = 16

< YCgCo-R, even addition of bits



AVCOL_SPC_YCGCO_RO = 17

< YCgCo-R, odd addition of bits



AVCOL_SPC_NB = 18

< Not part of ABI

实现

源代码

impl AVColorSpace

源代码

pub const AVCOL_SPC_YCOCG: AVColorSpace = AVColorSpace::AVCOL_SPC_YCGCO

trait 实现

源代码

impl Clone for AVColorSpace

源代码

fn clone(&self) -> AVColorSpace

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVColorSpace

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl Hash for AVColorSpace

源代码

fn hash<__H: Hasher>(&self, state: &mut __H)

Feeds this value into the given Hasher. 阅读更多
1.3.0 · 源代码

fn hash_slice<H>(data: &[Self], state: &mut H)
where H: Hasher, Self: Sized,

Feeds a slice of this type into the given Hasher. 阅读更多
源代码

impl PartialEq for AVColorSpace

源代码

fn eq(&self, other: &AVColorSpace) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVColorSpace

源代码

impl Eq for AVColorSpace

源代码

impl StructuralPartialEq for AVColorSpace

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。