#[repr(i32)]pub enum AVDurationEstimationMethod {
AVFMT_DURATION_FROM_PTS = 0,
AVFMT_DURATION_FROM_STREAM = 1,
AVFMT_DURATION_FROM_BITRATE = 2,
}展开描述
The duration of a video can be estimated through various ways, and this enum can be used to know how the duration was estimated.
Variants
AVFMT_DURATION_FROM_PTS = 0
< Duration accurately estimated from PTSes
AVFMT_DURATION_FROM_STREAM = 1
< Duration estimated from a stream with a known duration
AVFMT_DURATION_FROM_BITRATE = 2
< Duration estimated from bitrate (less accurate)
trait 实现
源代码impl Clone for AVDurationEstimationMethod
impl Clone for AVDurationEstimationMethod
源代码fn clone(&self) -> AVDurationEstimationMethod
fn clone(&self) -> AVDurationEstimationMethod
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVDurationEstimationMethod
impl Debug for AVDurationEstimationMethod
源代码impl Hash for AVDurationEstimationMethod
impl Hash for AVDurationEstimationMethod
源代码impl PartialEq for AVDurationEstimationMethod
impl PartialEq for AVDurationEstimationMethod
impl Copy for AVDurationEstimationMethod
impl Eq for AVDurationEstimationMethod
impl StructuralPartialEq for AVDurationEstimationMethod
自动 trait 实现
impl Freeze for AVDurationEstimationMethod
impl RefUnwindSafe for AVDurationEstimationMethod
impl Send for AVDurationEstimationMethod
impl Sync for AVDurationEstimationMethod
impl Unpin for AVDurationEstimationMethod
impl UnsafeUnpin for AVDurationEstimationMethod
impl UnwindSafe for AVDurationEstimationMethod
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多