#[repr(i32)]pub enum AVFormatCommandID {
AVFORMAT_COMMAND_RTSP_SET_PARAMETER = 0,
}展开描述
Command IDs that can be sent to the demuxer
The following commands can be sent to a demuxer using ::avformat_send_command.
Variants
AVFORMAT_COMMAND_RTSP_SET_PARAMETER = 0
Send a RTSP SET_PARAMETER request to the server
Sends an SET_PARAMETER RTSP command to the server, with a data payload of type ::AVRTSPCommandRequest, ownership of it and its data remains with the caller.
A reply retrieved is of type ::AVRTSPResponse and it and its contents must be freed by the caller.
trait 实现
源代码impl Clone for AVFormatCommandID
impl Clone for AVFormatCommandID
源代码fn clone(&self) -> AVFormatCommandID
fn clone(&self) -> AVFormatCommandID
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVFormatCommandID
impl Debug for AVFormatCommandID
源代码impl Hash for AVFormatCommandID
impl Hash for AVFormatCommandID
源代码impl PartialEq for AVFormatCommandID
impl PartialEq for AVFormatCommandID
impl Copy for AVFormatCommandID
impl Eq for AVFormatCommandID
impl StructuralPartialEq for AVFormatCommandID
自动 trait 实现
impl Freeze for AVFormatCommandID
impl RefUnwindSafe for AVFormatCommandID
impl Send for AVFormatCommandID
impl Sync for AVFormatCommandID
impl Unpin for AVFormatCommandID
impl UnsafeUnpin for AVFormatCommandID
impl UnwindSafe for AVFormatCommandID
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多