#[repr(i32)]pub enum AVOptionType {
Show 21 variants
AV_OPT_TYPE_FLAGS = 1,
AV_OPT_TYPE_INT = 2,
AV_OPT_TYPE_INT64 = 3,
AV_OPT_TYPE_DOUBLE = 4,
AV_OPT_TYPE_FLOAT = 5,
AV_OPT_TYPE_STRING = 6,
AV_OPT_TYPE_RATIONAL = 7,
AV_OPT_TYPE_BINARY = 8,
AV_OPT_TYPE_DICT = 9,
AV_OPT_TYPE_UINT64 = 10,
AV_OPT_TYPE_CONST = 11,
AV_OPT_TYPE_IMAGE_SIZE = 12,
AV_OPT_TYPE_PIXEL_FMT = 13,
AV_OPT_TYPE_SAMPLE_FMT = 14,
AV_OPT_TYPE_VIDEO_RATE = 15,
AV_OPT_TYPE_DURATION = 16,
AV_OPT_TYPE_COLOR = 17,
AV_OPT_TYPE_BOOL = 18,
AV_OPT_TYPE_CHLAYOUT = 19,
AV_OPT_TYPE_UINT = 20,
AV_OPT_TYPE_FLAG_ARRAY = 65_536,
}展开描述
An option type determines:
- for native access, the underlying C type of the field that an AVOption refers to;
- for foreign access, the semantics of accessing the option through this API, e.g. which av_opt_get_() and av_opt_set_() functions can be called, or what format will av_opt_get()/av_opt_set() expect/produce.
Variants
AV_OPT_TYPE_FLAGS = 1
Underlying C type is unsigned int.
AV_OPT_TYPE_INT = 2
Underlying C type is int.
AV_OPT_TYPE_INT64 = 3
Underlying C type is int64_t.
AV_OPT_TYPE_DOUBLE = 4
Underlying C type is double.
AV_OPT_TYPE_FLOAT = 5
Underlying C type is float.
AV_OPT_TYPE_STRING = 6
Underlying C type is a uint8_t* that is either NULL or points to a C string allocated with the av_malloc() family of functions.
AV_OPT_TYPE_RATIONAL = 7
Underlying C type is AVRational.
AV_OPT_TYPE_BINARY = 8
Underlying C type is a uint8_t* that is either NULL or points to an array allocated with the av_malloc() family of functions. The pointer is immediately followed by an int containing the array length in bytes.
AV_OPT_TYPE_DICT = 9
Underlying C type is AVDictionary*.
AV_OPT_TYPE_UINT64 = 10
Underlying C type is uint64_t.
AV_OPT_TYPE_CONST = 11
Special option type for declaring named constants. Does not correspond to an actual field in the object, offset must be 0.
AV_OPT_TYPE_IMAGE_SIZE = 12
Underlying C type is two consecutive integers.
AV_OPT_TYPE_PIXEL_FMT = 13
Underlying C type is enum AVPixelFormat.
AV_OPT_TYPE_SAMPLE_FMT = 14
Underlying C type is enum AVSampleFormat.
AV_OPT_TYPE_VIDEO_RATE = 15
Underlying C type is AVRational.
AV_OPT_TYPE_DURATION = 16
Underlying C type is int64_t.
AV_OPT_TYPE_COLOR = 17
Underlying C type is uint8_t[4].
AV_OPT_TYPE_BOOL = 18
Underlying C type is int.
AV_OPT_TYPE_CHLAYOUT = 19
Underlying C type is AVChannelLayout.
AV_OPT_TYPE_UINT = 20
Underlying C type is unsigned int.
AV_OPT_TYPE_FLAG_ARRAY = 65_536
May be combined with another regular option type to declare an array option.
For array options, @ref AVOption.offset should refer to a pointer corresponding to the option type. The pointer should be immediately followed by an unsigned int that will store the number of elements in the array.
trait 实现
源代码impl Clone for AVOptionType
impl Clone for AVOptionType
源代码fn clone(&self) -> AVOptionType
fn clone(&self) -> AVOptionType
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source 执行拷贝赋值。 阅读更多