#[repr(i32)]pub enum AVStreamParseType {
AVSTREAM_PARSE_NONE = 0,
AVSTREAM_PARSE_FULL = 1,
AVSTREAM_PARSE_HEADERS = 2,
AVSTREAM_PARSE_TIMESTAMPS = 3,
AVSTREAM_PARSE_FULL_ONCE = 4,
AVSTREAM_PARSE_FULL_RAW = 5,
}展开描述
@}
Variants
AVSTREAM_PARSE_NONE = 0
AVSTREAM_PARSE_FULL = 1
< full parsing and repack
AVSTREAM_PARSE_HEADERS = 2
< Only parse headers, do not repack.
AVSTREAM_PARSE_TIMESTAMPS = 3
< full parsing and interpolation of timestamps for frames not starting on a packet boundary
AVSTREAM_PARSE_FULL_ONCE = 4
< full parsing and repack of the first frame only, only implemented for H.264 currently
AVSTREAM_PARSE_FULL_RAW = 5
< full parsing and repack with timestamp and position generation by parser for raw this assumes that each packet in the file contains no demuxer level headers and just codec level data, otherwise position generation would fail
trait 实现
源代码impl Clone for AVStreamParseType
impl Clone for AVStreamParseType
源代码fn clone(&self) -> AVStreamParseType
fn clone(&self) -> AVStreamParseType
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVStreamParseType
impl Debug for AVStreamParseType
源代码impl Hash for AVStreamParseType
impl Hash for AVStreamParseType
源代码impl PartialEq for AVStreamParseType
impl PartialEq for AVStreamParseType
impl Copy for AVStreamParseType
impl Eq for AVStreamParseType
impl StructuralPartialEq for AVStreamParseType
自动 trait 实现
impl Freeze for AVStreamParseType
impl RefUnwindSafe for AVStreamParseType
impl Send for AVStreamParseType
impl Sync for AVStreamParseType
impl Unpin for AVStreamParseType
impl UnsafeUnpin for AVStreamParseType
impl UnwindSafe for AVStreamParseType
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多