#[repr(i32)]pub enum AVSubtitleType {
SUBTITLE_NONE = 0,
SUBTITLE_BITMAP = 1,
SUBTITLE_TEXT = 2,
SUBTITLE_ASS = 3,
}展开描述
@}
Variants
SUBTITLE_NONE = 0
SUBTITLE_BITMAP = 1
< A bitmap, pict will be set
SUBTITLE_TEXT = 2
Plain text, the text field must be set by the decoder and is authoritative. ass and pict fields may contain approximations.
SUBTITLE_ASS = 3
Formatted text, the ass field must be set by the decoder and is authoritative. pict and text fields may contain approximations.
trait 实现
源代码impl Clone for AVSubtitleType
impl Clone for AVSubtitleType
源代码fn clone(&self) -> AVSubtitleType
fn clone(&self) -> AVSubtitleType
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVSubtitleType
impl Debug for AVSubtitleType
源代码impl Hash for AVSubtitleType
impl Hash for AVSubtitleType
源代码impl PartialEq for AVSubtitleType
impl PartialEq for AVSubtitleType
impl Copy for AVSubtitleType
impl Eq for AVSubtitleType
impl StructuralPartialEq for AVSubtitleType
自动 trait 实现
impl Freeze for AVSubtitleType
impl RefUnwindSafe for AVSubtitleType
impl Send for AVSubtitleType
impl Sync for AVSubtitleType
impl Unpin for AVSubtitleType
impl UnsafeUnpin for AVSubtitleType
impl UnwindSafe for AVSubtitleType
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多