跳到主要内容

av_buffer_pool_init

搜索

函数 av_buffer_pool_init 

源代码
pub unsafe extern "C" fn av_buffer_pool_init(
    size: usize,
    alloc: Option<unsafe extern "C" fn(size: usize) -> *mut AVBufferRef>,
) -> *mut AVBufferPool
展开描述

Allocate and initialize a buffer pool.

@param size size of each buffer in this pool @param alloc a function that will be used to allocate new buffers when the pool is empty. May be NULL, then the default allocator will be used (av_buffer_alloc()). @return newly created buffer pool on success, NULL on error.