跳到主要内容

av_buffer_pool_uninit

搜索

函数 av_buffer_pool_uninit 

源代码
pub unsafe extern "C" fn av_buffer_pool_uninit(
    pool: *mut *mut AVBufferPool,
)
展开描述

Mark the pool as being available for freeing. It will actually be freed only once all the allocated buffers associated with the pool are released. Thus it is safe to call this function while some of the allocated buffers are still in use.

@param pool pointer to the pool to be freed. It will be set to NULL.