跳到主要内容

av_buffer_unref

搜索

函数 av_buffer_unref 

源代码
pub unsafe extern "C" fn av_buffer_unref(buf: *mut *mut AVBufferRef)
展开描述

Free a given reference and automatically free the buffer if there are no more references to it.

@param buf the reference to be freed. The pointer is set to NULL on return.