pub unsafe extern "C" fn av_buffersrc_get_status(
ctx: *mut AVFilterContext,
) -> c_int展开描述
Returns 0 or a negative AVERROR code. Currently, this will only ever return AVERROR(EOF), to indicate that the buffer source has been closed, either as a result of av_buffersrc_close(), or because the downstream filter is no longer accepting new data.