跳到主要内容

av_channel_layout_ambisonic_order

搜索

函数 av_channel_layout_ambisonic_order 

源代码
pub unsafe extern "C" fn av_channel_layout_ambisonic_order(
    channel_layout: *const AVChannelLayout,
) -> c_int
展开描述

Return the order if the layout is n-th order standard-order ambisonic. The presence of optional extra non-diegetic channels at the end is not taken into account.

@param channel_layout input channel layout @return the order of the layout, a negative error code otherwise.