跳到主要内容

av_channel_layout_index_from_string

搜索

函数 av_channel_layout_index_from_string 

源代码
pub unsafe extern "C" fn av_channel_layout_index_from_string(
    channel_layout: *const AVChannelLayout,
    name: *const c_char,
) -> c_int
展开描述

Get the index in a channel layout of a channel described by the given string. In case multiple channels are found, only the first match will be returned.

This function accepts channel names in the same format as @ref av_channel_from_string().

@param channel_layout input channel layout @param name string describing the channel whose index to obtain @return a channel index described by the given string, or a negative AVERROR value.