跳到主要内容

av_cpb_properties_alloc

搜索

函数 av_cpb_properties_alloc 

源代码
pub unsafe extern "C" fn av_cpb_properties_alloc(
    size: *mut usize,
) -> *mut AVCPBProperties
展开描述

Allocate a CPB properties structure and initialize its fields to default values.

@param size if non-NULL, the size of the allocated struct will be written here. This is useful for embedding it in side data.

@return the newly allocated struct or NULL on failure