pub unsafe extern "C" fn av_disposition_from_string( disp: *const c_char, ) -> c_int
@return The AV_DISPOSITION_* flag corresponding to disp or a negative error code if disp does not correspond to a known stream disposition.