跳到主要内容

av_expr_eval

搜索

函数 av_expr_eval 

源代码
pub unsafe extern "C" fn av_expr_eval(
    e: *mut AVExpr,
    const_values: *const f64,
    opaque: *mut c_void,
) -> f64
展开描述

Evaluate a previously parsed expression.

@param e the AVExpr to evaluate @param const_values a zero terminated array of values for the identifiers from av_expr_parse() const_names @param opaque a pointer which will be passed to all functions from funcs1 and funcs2 @return the value of the expression