跳到主要内容

av_file_unmap

搜索

函数 av_file_unmap 

源代码
pub unsafe extern "C" fn av_file_unmap(bufptr: *mut u8, size: usize)
展开描述

Unmap or free the buffer bufptr created by av_file_map().

@param bufptr the buffer previously created with av_file_map() @param size size in bytes of bufptr, must be the same as returned by av_file_map()