pub unsafe extern "C" fn av_find_input_format(
short_name: *const c_char,
) -> *const AVInputFormat展开描述
Find AVInputFormat based on the short name of the input format.
pub unsafe extern "C" fn av_find_input_format(
short_name: *const c_char,
) -> *const AVInputFormatFind AVInputFormat based on the short name of the input format.