跳到主要内容

av_find_program_from_stream

搜索

函数 av_find_program_from_stream 

源代码
pub unsafe extern "C" fn av_find_program_from_stream(
    ic: *mut AVFormatContext,
    last: *mut AVProgram,
    s: c_int,
) -> *mut AVProgram
展开描述

Find the programs which belong to a given stream.

@param ic media file handle @param last the last found program, the search will start after this program, or from the beginning if it is NULL @param s stream index

@return the next program which belongs to s, NULL if no program is found or the last program is not among the programs of ic.