跳到主要内容

av_get_alt_sample_fmt

搜索

函数 av_get_alt_sample_fmt 

源代码
pub unsafe extern "C" fn av_get_alt_sample_fmt(
    sample_fmt: AVSampleFormat,
    planar: c_int,
) -> AVSampleFormat
展开描述

Return the planar<->packed alternative form of the given sample format, or AV_SAMPLE_FMT_NONE on error. If the passed sample_fmt is already in the requested planar/packed format, the format returned is the same as the input.