跳到主要内容

av_get_known_color_name

搜索

函数 av_get_known_color_name 

源代码
pub unsafe extern "C" fn av_get_known_color_name(
    color_idx: c_int,
    rgb: *mut *const u8,
) -> *const c_char
展开描述

Get the name of a color from the internal table of hard-coded named colors.

This function is meant to enumerate the color names recognized by av_parse_color().

@param color_idx index of the requested color, starting from 0 @param rgb if not NULL, will point to a 3-elements array with the color value in RGB @return the color name string or NULL if color_idx is not in the array