跳到主要内容

av_hex_dump

搜索

函数 av_hex_dump 

源代码
pub unsafe extern "C" fn av_hex_dump(
    f: *mut FILE,
    buf: *const u8,
    size: c_int,
)
展开描述

Send a nice hexadecimal dump of a buffer to the specified file stream.

@param f The file stream pointer where the dump should be sent to. @param buf buffer @param size buffer size

@see av_hex_dump_log, av_pkt_dump2, av_pkt_dump_log2