跳到主要内容

av_hwdevice_iterate_types

搜索

函数 av_hwdevice_iterate_types 

源代码
pub unsafe extern "C" fn av_hwdevice_iterate_types(
    prev: AVHWDeviceType,
) -> AVHWDeviceType
展开描述

Iterate over supported device types.

@param prev AV_HWDEVICE_TYPE_NONE initially, then the previous type returned by this function in subsequent iterations. @return The next usable device type from enum AVHWDeviceType, or AV_HWDEVICE_TYPE_NONE if there are no more.