pub unsafe extern "C" fn av_image_copy(
dst_data: *const *mut u8,
dst_linesizes: *const c_int,
src_data: *const *const u8,
src_linesizes: *const c_int,
pix_fmt: AVPixelFormat,
width: c_int,
height: c_int,
)展开描述
Copy image in src_data to dst_data.
@param dst_data destination image data buffer to copy to @param dst_linesizes linesizes for the image in dst_data @param src_data source image data buffer to copy from @param src_linesizes linesizes for the image in src_data @param pix_fmt the AVPixelFormat of the image @param width width of the image in pixels @param height height of the image in pixels