跳到主要内容

av_index_search_timestamp

搜索

函数 av_index_search_timestamp 

源代码
pub unsafe extern "C" fn av_index_search_timestamp(
    st: *mut AVStream,
    timestamp: i64,
    flags: c_int,
) -> c_int
展开描述

Get the index for a specific timestamp.

@param st stream that the timestamp belongs to @param timestamp timestamp to retrieve the index for @param flags if AVSEEK_FLAG_BACKWARD then the returned index will correspond to the timestamp which is <= the requested one, if backward is 0, then it will be >= if AVSEEK_FLAG_ANY seek to any frame, only keyframes otherwise @return < 0 if no such timestamp could be found