跳到主要内容

av_mallocz

搜索

函数 av_mallocz 

源代码
pub unsafe extern "C" fn av_mallocz(size: usize) -> *mut c_void
展开描述

Allocate a memory block with alignment suitable for all memory accesses (including vectors if available on the CPU) and zero all the bytes of the block.

@param size Size in bytes for the memory block to be allocated @return Pointer to the allocated block, or NULL if it cannot be allocated @see av_malloc()