跳到主要内容

av_opt_get_chlayout

搜索

函数 av_opt_get_chlayout 

源代码
pub unsafe extern "C" fn av_opt_get_chlayout(
    obj: *mut c_void,
    name: *const c_char,
    search_flags: c_int,
    layout: *mut AVChannelLayout,
) -> c_int
展开描述

@param[out] layout The returned layout is a copy of the actual value and must be freed with av_channel_layout_uninit() by the caller