跳到主要内容

av_opt_get_dict_val

搜索

函数 av_opt_get_dict_val 

源代码
pub unsafe extern "C" fn av_opt_get_dict_val(
    obj: *mut c_void,
    name: *const c_char,
    search_flags: c_int,
    out_val: *mut *mut AVDictionary,
) -> c_int
展开描述

@param[out] out_val The returned dictionary is a copy of the actual value and must be freed with av_dict_free() by the caller