跳到主要内容

av_packet_side_data_get

搜索

函数 av_packet_side_data_get 

源代码
pub unsafe extern "C" fn av_packet_side_data_get(
    sd: *const AVPacketSideData,
    nb_sd: c_int,
    type_: AVPacketSideDataType,
) -> *const AVPacketSideData
展开描述

Get side information from a side data array.

@param sd the array from which the side data should be fetched @param nb_sd value containing the number of entries in the array. @param type desired side information type

@return pointer to side data if present or NULL otherwise