跳到主要内容

av_parse_video_rate

搜索

函数 av_parse_video_rate 

源代码
pub unsafe extern "C" fn av_parse_video_rate(
    rate: *mut AVRational,
    str_: *const c_char,
) -> c_int
展开描述

Parse str and store the detected values in *rate.

@param[in,out] rate pointer to the AVRational which will contain the detected frame rate @param[in] str the string to parse: it has to be a string in the format rate_num / rate_den, a float number or a valid video rate abbreviation @return >= 0 on success, a negative error code otherwise