跳到主要内容

av_stristr

搜索

函数 av_stristr 

源代码
pub unsafe extern "C" fn av_stristr(
    haystack: *const c_char,
    needle: *const c_char,
) -> *mut c_char
展开描述

Locate the first case-independent occurrence in the string haystack of the string needle. A zero-length string needle is considered to match at the start of haystack.

This function is a case-insensitive version of the standard strstr().

@param haystack string to search in @param needle string to search for @return pointer to the located match within haystack or a null pointer if no match