pub unsafe extern "C" fn av_thread_message_queue_free(
mq: *mut *mut AVThreadMessageQueue,
)展开描述
Free a message queue.
The message queue must no longer be in use by another thread.
pub unsafe extern "C" fn av_thread_message_queue_free(
mq: *mut *mut AVThreadMessageQueue,
)Free a message queue.
The message queue must no longer be in use by another thread.