跳到主要内容

av_write_trailer

搜索

函数 av_write_trailer 

源代码
pub unsafe extern "C" fn av_write_trailer(
    s: *mut AVFormatContext,
) -> c_int
展开描述

Write the stream trailer to an output media file and free the file private data.

May only be called after a successful call to avformat_write_header.

@param s media file handle @return 0 if OK, AVERROR_xxx on error