跳到主要内容

avcodec_parameters_copy

搜索

函数 avcodec_parameters_copy 

源代码
pub unsafe extern "C" fn avcodec_parameters_copy(
    dst: *mut AVCodecParameters,
    src: *const AVCodecParameters,
) -> c_int
展开描述

Copy the contents of src to dst. Any allocated fields in dst are freed and replaced with newly allocated duplicates of the corresponding fields in src.

@return >= 0 on success, a negative AVERROR code on failure.