跳到主要内容

avfilter_link

搜索

函数 avfilter_link 

源代码
pub unsafe extern "C" fn avfilter_link(
    src: *mut AVFilterContext,
    srcpad: c_uint,
    dst: *mut AVFilterContext,
    dstpad: c_uint,
) -> c_int
展开描述

Link two filters together.

@param src the source filter @param srcpad index of the output pad on the source filter @param dst the destination filter @param dstpad index of the input pad on the destination filter @return zero on success