跳到主要内容

avformat_send_command

搜索

函数 avformat_send_command 

源代码
pub unsafe extern "C" fn avformat_send_command(
    s: *mut AVFormatContext,
    id: AVFormatCommandID,
    data: *mut c_void,
) -> c_int
展开描述

Send a command to the demuxer

Sends the specified command and (depending on the command) optionally a command-specific payload to the demuxer to handle.

@param s Format context, must be allocated with ::avformat_alloc_context. @param id Identifier of type ::AVFormatCommandID, indicating the command to send. @param data Command-specific data, allocated by the caller and ownership remains with the caller. For details what is expected here, consult the documentation of the respective ::AVFormatCommandID.