跳到主要内容

avio_accept

搜索

函数 avio_accept 

源代码
pub unsafe extern "C" fn avio_accept(
    s: *mut AVIOContext,
    c: *mut *mut AVIOContext,
) -> c_int
展开描述

Accept and allocate a client context on a server context. @param s the server context @param c the client context, must be unallocated @return >= 0 on success or a negative value corresponding to an AVERROR on failure