跳到主要内容

avio_get_str16le

搜索

函数 avio_get_str16le 

源代码
pub unsafe extern "C" fn avio_get_str16le(
    pb: *mut AVIOContext,
    maxlen: c_int,
    buf: *mut c_char,
    buflen: c_int,
) -> c_int
展开描述

Read a UTF-16 string from pb and convert it to UTF-8. The reading will terminate when either a null or invalid character was encountered or maxlen bytes have been read. @return number of bytes read (is always <= maxlen)