跳到主要内容

avio_open_dir

搜索

函数 avio_open_dir 

源代码
pub unsafe extern "C" fn avio_open_dir(
    s: *mut *mut AVIODirContext,
    url: *const c_char,
    options: *mut *mut AVDictionary,
) -> c_int
展开描述

Open directory for reading.

@param s directory read context. Pointer to a NULL pointer must be passed. @param url directory to be listed. @param options A dictionary filled with protocol-private options. On return this parameter will be destroyed and replaced with a dictionary containing options that were not found. May be NULL. @return >=0 on success or negative on error.