跳到主要内容

sws_frame_setup

搜索

函数 sws_frame_setup 

源代码
pub unsafe extern "C" fn sws_frame_setup(
    ctx: *mut SwsContext,
    dst: *const AVFrame,
    src: *const AVFrame,
) -> c_int
展开描述

Like sws_scale_frame, but without actually scaling. It will instead merely initialize internal state that would be required to perform the operation, as well as returning the correct error code for unsupported frame combinations.

@param ctx The scaling context. @param dst The destination frame to consider. @param src The source frame to consider. @return 0 on success, a negative AVERROR code on failure.