跳到主要内容

sws_init_context

搜索

函数 sws_init_context 

源代码
pub unsafe extern "C" fn sws_init_context(
    sws_context: *mut SwsContext,
    srcFilter: *mut SwsFilter,
    dstFilter: *mut SwsFilter,
) -> c_int
展开描述

Initialize the swscaler context sws_context.

This function is considered deprecated, and provided only for backwards compatibility with sws_scale() and sws_frame_start(). The preferred way to use libswscale is to set all frame properties correctly and call sws_scale_frame() directly, without explicitly initializing the context.

@return zero or positive value on success, a negative value on error