#[repr(C)]pub struct AVChannelCustom {
pub id: AVChannel,
pub name: [c_char; 16],
pub opaque: *mut c_void,
}展开描述
An AVChannelCustom defines a single channel within a custom order layout
Unlike most structures in FFmpeg, sizeof(AVChannelCustom) is a part of the public ABI.
No new fields may be added to it without a major version bump.
Fields
id: AVChannelname: [c_char; 16]opaque: *mut c_voidtrait 实现
源代码impl Clone for AVChannelCustom
impl Clone for AVChannelCustom
源代码fn clone(&self) -> AVChannelCustom
fn clone(&self) -> AVChannelCustom
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVChannelCustom
impl Debug for AVChannelCustom
源代码impl PartialEq for AVChannelCustom
impl PartialEq for AVChannelCustom
impl Copy for AVChannelCustom
impl Eq for AVChannelCustom
impl StructuralPartialEq for AVChannelCustom
自动 trait 实现
impl Freeze for AVChannelCustom
impl RefUnwindSafe for AVChannelCustom
impl !Send for AVChannelCustom
impl !Sync for AVChannelCustom
impl Unpin for AVChannelCustom
impl UnsafeUnpin for AVChannelCustom
impl UnwindSafe for AVChannelCustom
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多