#[repr(C)]pub struct AVCodecDescriptor {
pub id: AVCodecID,
pub type_: AVMediaType,
pub name: *const c_char,
pub long_name: *const c_char,
pub props: c_int,
pub mime_types: *const *const c_char,
pub profiles: *const AVProfile,
}展开描述
This struct describes the properties of a single codec described by an AVCodecID. @see avcodec_descriptor_get()
Fields
id: AVCodecIDtype_: AVMediaTypename: *const c_charName of the codec described by this descriptor. It is non-empty and unique for each codec descriptor. It should contain alphanumeric characters and ‘_’ only.
long_name: *const c_charA more descriptive name for this codec. May be NULL.
props: c_intCodec properties, a combination of AV_CODEC_PROP_* flags.
mime_types: *const *const c_charMIME type(s) associated with the codec. May be NULL; if not, a NULL-terminated array of MIME types. The first item is always non-NULL and is the preferred MIME type.
profiles: *const AVProfileIf non-NULL, an array of profiles recognized for this codec. Terminated with AV_PROFILE_UNKNOWN.
trait 实现
源代码impl Clone for AVCodecDescriptor
impl Clone for AVCodecDescriptor
源代码fn clone(&self) -> AVCodecDescriptor
fn clone(&self) -> AVCodecDescriptor
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVCodecDescriptor
impl Debug for AVCodecDescriptor
源代码impl PartialEq for AVCodecDescriptor
impl PartialEq for AVCodecDescriptor
impl Copy for AVCodecDescriptor
impl Eq for AVCodecDescriptor
impl StructuralPartialEq for AVCodecDescriptor
自动 trait 实现
impl Freeze for AVCodecDescriptor
impl RefUnwindSafe for AVCodecDescriptor
impl !Send for AVCodecDescriptor
impl !Sync for AVCodecDescriptor
impl Unpin for AVCodecDescriptor
impl UnsafeUnpin for AVCodecDescriptor
impl UnwindSafe for AVCodecDescriptor
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多