#[repr(C)]pub struct AVCodecHWConfig {
pub pix_fmt: AVPixelFormat,
pub methods: c_int,
pub device_type: AVHWDeviceType,
}Fields
pix_fmt: AVPixelFormatFor decoders, a hardware pixel format which that decoder may be able to decode to if suitable hardware is available.
For encoders, a pixel format which the encoder may be able to accept. If set to AV_PIX_FMT_NONE, this applies to all pixel formats supported by the codec.
methods: c_intBit set of AV_CODEC_HW_CONFIG_METHOD_* flags, describing the possible setup methods which can be used with this configuration.
device_type: AVHWDeviceTypeThe device type associated with the configuration.
Must be set for AV_CODEC_HW_CONFIG_METHOD_HW_DEVICE_CTX and AV_CODEC_HW_CONFIG_METHOD_HW_FRAMES_CTX, otherwise unused.
trait 实现
源代码impl Clone for AVCodecHWConfig
impl Clone for AVCodecHWConfig
源代码fn clone(&self) -> AVCodecHWConfig
fn clone(&self) -> AVCodecHWConfig
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVCodecHWConfig
impl Debug for AVCodecHWConfig
源代码impl PartialEq for AVCodecHWConfig
impl PartialEq for AVCodecHWConfig
impl Copy for AVCodecHWConfig
impl Eq for AVCodecHWConfig
impl StructuralPartialEq for AVCodecHWConfig
自动 trait 实现
impl Freeze for AVCodecHWConfig
impl RefUnwindSafe for AVCodecHWConfig
impl Send for AVCodecHWConfig
impl Sync for AVCodecHWConfig
impl Unpin for AVCodecHWConfig
impl UnsafeUnpin for AVCodecHWConfig
impl UnwindSafe for AVCodecHWConfig
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多