#[repr(C)]pub struct AVComponentDescriptor {
pub plane: c_int,
pub step: c_int,
pub offset: c_int,
pub shift: c_int,
pub depth: c_int,
}Fields
plane: c_intWhich of the 4 planes contains the component.
step: c_intNumber of elements between 2 horizontally consecutive pixels. Elements are bits for bitstream formats, bytes otherwise.
offset: c_intNumber of elements before the component of the first pixel. Elements are bits for bitstream formats, bytes otherwise.
shift: c_intNumber of least significant bits that must be shifted away to get the value.
depth: c_intNumber of bits in the component.
trait 实现
源代码impl Clone for AVComponentDescriptor
impl Clone for AVComponentDescriptor
源代码fn clone(&self) -> AVComponentDescriptor
fn clone(&self) -> AVComponentDescriptor
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVComponentDescriptor
impl Debug for AVComponentDescriptor
源代码impl PartialEq for AVComponentDescriptor
impl PartialEq for AVComponentDescriptor
impl Copy for AVComponentDescriptor
impl Eq for AVComponentDescriptor
impl StructuralPartialEq for AVComponentDescriptor
自动 trait 实现
impl Freeze for AVComponentDescriptor
impl RefUnwindSafe for AVComponentDescriptor
impl Send for AVComponentDescriptor
impl Sync for AVComponentDescriptor
impl Unpin for AVComponentDescriptor
impl UnsafeUnpin for AVComponentDescriptor
impl UnwindSafe for AVComponentDescriptor
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多