跳到主要内容

AVDVProfile

搜索

结构体 AVDVProfile 

源代码
#[repr(C)]
pub struct AVDVProfile {
Show 17 fields pub dsf: c_int, pub video_stype: c_int, pub frame_size: c_int, pub difseg_size: c_int, pub n_difchan: c_int, pub time_base: AVRational, pub ltc_divisor: c_int, pub height: c_int, pub width: c_int, pub sar: [AVRational; 2], pub pix_fmt: AVPixelFormat, pub bpm: c_int, pub block_sizes: *const u8, pub audio_stride: c_int, pub audio_min_samples: [c_int; 3], pub audio_samples_dist: [c_int; 5], pub audio_shuffle: *const [c_uchar; 9],
}

Fields

dsf: c_intvideo_stype: c_intframe_size: c_intdifseg_size: c_intn_difchan: c_inttime_base: AVRationalltc_divisor: c_intheight: c_intwidth: c_intsar: [AVRational; 2]pix_fmt: AVPixelFormatbpm: c_intblock_sizes: *const u8audio_stride: c_intaudio_min_samples: [c_int; 3]audio_samples_dist: [c_int; 5]audio_shuffle: *const [c_uchar; 9]

trait 实现

源代码

impl Clone for AVDVProfile

源代码

fn clone(&self) -> AVDVProfile

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVDVProfile

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVDVProfile

源代码

fn eq(&self, other: &AVDVProfile) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVDVProfile

源代码

impl Eq for AVDVProfile

源代码

impl StructuralPartialEq for AVDVProfile

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。