跳到主要内容

AVFilter

搜索

结构体 AVFilter 

源代码
#[repr(C)]
pub struct AVFilter { pub name: *const c_char, pub description: *const c_char, pub inputs: *const AVFilterPad, pub outputs: *const AVFilterPad, pub priv_class: *const AVClass, pub flags: c_int, }
展开描述

Filter definition. This defines the pads a filter contains, and all the callback functions used to interact with the filter.

Fields

name: *const c_char

Filter name. Must be non-NULL and unique among filters.

description: *const c_char

A description of the filter. May be NULL.

You should use the NULL_IF_CONFIG_SMALL() macro to define it.

inputs: *const AVFilterPad

List of static inputs.

NULL if there are no (static) inputs. Instances of filters with AVFILTER_FLAG_DYNAMIC_INPUTS set may have more inputs than present in this list.

outputs: *const AVFilterPad

List of static outputs.

NULL if there are no (static) outputs. Instances of filters with AVFILTER_FLAG_DYNAMIC_OUTPUTS set may have more outputs than present in this list.

priv_class: *const AVClass

A class for the private data, used to declare filter private AVOptions. This field is NULL for filters that do not declare any options.

If this field is non-NULL, the first member of the filter private data must be a pointer to AVClass, which will be set by libavfilter generic code to this class.

flags: c_int

A combination of AVFILTER_FLAG_*

trait 实现

源代码

impl Clone for AVFilter

源代码

fn clone(&self) -> AVFilter

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVFilter

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVFilter

源代码

fn eq(&self, other: &AVFilter) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVFilter

源代码

impl Eq for AVFilter

源代码

impl StructuralPartialEq for AVFilter

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。