跳到主要内容

AVFilterContext

搜索

结构体 AVFilterContext 

源代码
#[repr(C)]
pub struct AVFilterContext {
Show 21 fields pub av_class: *const AVClass, pub filter: *const AVFilter, pub name: *mut c_char, pub input_pads: *mut AVFilterPad, pub inputs: *mut *mut AVFilterLink, pub nb_inputs: c_uint, pub output_pads: *mut AVFilterPad, pub outputs: *mut *mut AVFilterLink, pub nb_outputs: c_uint, pub priv_: *mut c_void, pub graph: *mut AVFilterGraph, pub thread_type: c_int, pub nb_threads: c_int, pub command_queue: *mut AVFilterCommand, pub enable_str: *mut c_char, pub enable: *mut c_void, pub var_values: *mut f64, pub is_disabled: c_int, pub hw_device_ctx: *mut AVBufferRef, pub ready: c_uint, pub extra_hw_frames: c_int,
}
展开描述

An instance of a filter

Fields

av_class: *const AVClass

< needed for av_log() and filters common options

filter: *const AVFilter

< the AVFilter of which this is an instance

name: *mut c_char

< name of this filter instance

input_pads: *mut AVFilterPad

< array of input pads

inputs: *mut *mut AVFilterLink

< array of pointers to input links

nb_inputs: c_uint

< number of input pads

output_pads: *mut AVFilterPad

< array of output pads

outputs: *mut *mut AVFilterLink

< array of pointers to output links

nb_outputs: c_uint

< number of output pads

priv_: *mut c_void

< private data for use by the filter

graph: *mut AVFilterGraph

< filtergraph this filter belongs to

thread_type: c_int

Type of multithreading being allowed/used. A combination of AVFILTER_THREAD_* flags.

May be set by the caller before initializing the filter to forbid some or all kinds of multithreading for this filter. The default is allowing everything.

When the filter is initialized, this field is combined using bit AND with AVFilterGraph.thread_type to get the final mask used for determining allowed threading types. I.e. a threading type needs to be set in both to be allowed.

After the filter is initialized, libavfilter sets this field to the threading type that is actually used (0 for no multithreading).

nb_threads: c_int

Max number of threads allowed in this filter instance. If <= 0, its value is ignored. Overrides global number of threads set per filter graph.

command_queue: *mut AVFilterCommand

@deprecated unused

enable_str: *mut c_char

< enable expression string

enable: *mut c_void

@deprecated unused

var_values: *mut f64

@deprecated unused

is_disabled: c_int

MUST NOT be accessed from outside avfilter.

the enabled state from the last expression evaluation

hw_device_ctx: *mut AVBufferRef

For filters which will create hardware frames, sets the device the filter should create them in. All other filters will ignore this field: in particular, a filter which consumes or processes hardware frames will instead use the hw_frames_ctx field in AVFilterLink to carry the hardware context information.

May be set by the caller on filters flagged with AVFILTER_FLAG_HWDEVICE before initializing the filter with avfilter_init_str() or avfilter_init_dict().

ready: c_uint

@deprecated this field should never have been accessed by callers

extra_hw_frames: c_int

Sets the number of extra hardware frames which the filter will allocate on its output links for use in following filters or by the caller.

Some hardware filters require all frames that they will use for output to be defined in advance before filtering starts. For such filters, any hardware frame pools used for output must therefore be of fixed size. The extra frames set here are on top of any number that the filter needs internally in order to operate normally.

This field must be set before the graph containing this filter is configured.

trait 实现

源代码

impl Clone for AVFilterContext

源代码

fn clone(&self) -> AVFilterContext

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVFilterContext

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVFilterContext

源代码

fn eq(&self, other: &AVFilterContext) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVFilterContext

源代码

impl Eq for AVFilterContext

源代码

impl StructuralPartialEq for AVFilterContext

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。