跳到主要内容

AVFilterFormatsConfig

搜索

结构体 AVFilterFormatsConfig 

源代码
#[repr(C)]
pub struct AVFilterFormatsConfig { pub formats: *mut AVFilterFormats, pub samplerates: *mut AVFilterFormats, pub channel_layouts: *mut AVFilterChannelLayouts, pub color_spaces: *mut AVFilterFormats, pub color_ranges: *mut AVFilterFormats, pub alpha_modes: *mut AVFilterFormats, }
展开描述

Lists of formats / etc. supported by an end of a link.

This structure is directly part of AVFilterLink, in two copies: one for the source filter, one for the destination filter.

These lists are used for negotiating the format to actually be used, which will be loaded into the format and channel_layout members of AVFilterLink, when chosen.

Fields

formats: *mut AVFilterFormats

List of supported formats (pixel or sample).

samplerates: *mut AVFilterFormats

Lists of supported sample rates, only for audio.

channel_layouts: *mut AVFilterChannelLayouts

Lists of supported channel layouts, only for audio.

color_spaces: *mut AVFilterFormats

< AVColorSpace

color_ranges: *mut AVFilterFormats

< AVColorRange

alpha_modes: *mut AVFilterFormats

< AVAlphaMode

trait 实现

源代码

impl Clone for AVFilterFormatsConfig

源代码

fn clone(&self) -> AVFilterFormatsConfig

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVFilterFormatsConfig

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVFilterFormatsConfig

源代码

fn eq(&self, other: &AVFilterFormatsConfig) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVFilterFormatsConfig

源代码

impl Eq for AVFilterFormatsConfig

源代码

impl StructuralPartialEq for AVFilterFormatsConfig

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。