跳到主要内容

AVFilterGraph

搜索

结构体 AVFilterGraph 

源代码
#[repr(C)]
pub struct AVFilterGraph { pub av_class: *const AVClass, pub filters: *mut *mut AVFilterContext, pub nb_filters: c_uint, pub scale_sws_opts: *mut c_char, pub thread_type: c_int, pub nb_threads: c_int, pub opaque: *mut c_void, pub execute: avfilter_execute_func, pub aresample_swr_opts: *mut c_char, pub max_buffered_frames: c_uint, }

Fields

av_class: *const AVClassfilters: *mut *mut AVFilterContextnb_filters: c_uintscale_sws_opts: *mut c_char

< sws options to use for the auto-inserted scale filters

thread_type: c_int

Type of multithreading allowed for filters in this graph. A combination of AVFILTER_THREAD_* flags.

May be set by the caller at any point, the setting will apply to all filters initialized after that. The default is allowing everything.

When a filter in this graph is initialized, this field is combined using bit AND with AVFilterContext.thread_type to get the final mask used for determining allowed threading types. I.e. a threading type needs to be set in both to be allowed.

nb_threads: c_int

Maximum number of threads used by filters in this graph. May be set by the caller before adding any filters to the filtergraph. Zero (the default) means that the number of threads is determined automatically.

opaque: *mut c_void

Opaque user data. May be set by the caller to an arbitrary value, e.g. to be used from callbacks like @ref AVFilterGraph.execute. Libavfilter will not touch this field in any way.

execute: avfilter_execute_func

This callback may be set by the caller immediately after allocating the graph and before adding any filters to it, to provide a custom multithreading implementation.

If set, filters with slice threading capability will call this callback to execute multiple jobs in parallel.

If this field is left unset, libavfilter will use its internal implementation, which may or may not be multithreaded depending on the platform and build options.

aresample_swr_opts: *mut c_char

< swr options to use for the auto-inserted aresample filters, Access ONLY through AVOptions

max_buffered_frames: c_uint

Sets the maximum number of buffered frames in the filtergraph combined.

Zero means no limit. This field must be set before calling avfilter_graph_config().

trait 实现

源代码

impl Clone for AVFilterGraph

源代码

fn clone(&self) -> AVFilterGraph

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Debug for AVFilterGraph

源代码

fn fmt(&self, f: &mut Formatter<'_>) -> Result

使用给定的格式化器格式化该值。 阅读更多
源代码

impl PartialEq for AVFilterGraph

源代码

fn eq(&self, other: &AVFilterGraph) -> bool

Tests for self and other values to be equal, and is used by ==.
1.0.0 · 源代码

fn ne(&self, other: &Rhs) -> bool

测试 !=。默认实现几乎总是足够的,没有充分理由不应被重写。
源代码

impl Copy for AVFilterGraph

源代码

impl Eq for AVFilterGraph

源代码

impl StructuralPartialEq for AVFilterGraph

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。