#[repr(C)]pub struct AVHWFramesConstraints {
pub valid_hw_formats: *mut AVPixelFormat,
pub valid_sw_formats: *mut AVPixelFormat,
pub min_width: c_int,
pub min_height: c_int,
pub max_width: c_int,
pub max_height: c_int,
}展开描述
This struct describes the constraints on hardware frames attached to a given device with a hardware-specific configuration. This is returned by av_hwdevice_get_hwframe_constraints() and must be freed by av_hwframe_constraints_free() after use.
Fields
valid_hw_formats: *mut AVPixelFormatA list of possible values for format in the hw_frames_ctx, terminated by AV_PIX_FMT_NONE. This member will always be filled.
valid_sw_formats: *mut AVPixelFormatA list of possible values for sw_format in the hw_frames_ctx, terminated by AV_PIX_FMT_NONE. Can be NULL if this information is not known.
min_width: c_intThe minimum size of frames in this hw_frames_ctx. (Zero if not known.)
min_height: c_intmax_width: c_intThe maximum size of frames in this hw_frames_ctx. (INT_MAX if not known / no limit.)
max_height: c_inttrait 实现
源代码impl Clone for AVHWFramesConstraints
impl Clone for AVHWFramesConstraints
源代码fn clone(&self) -> AVHWFramesConstraints
fn clone(&self) -> AVHWFramesConstraints
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVHWFramesConstraints
impl Debug for AVHWFramesConstraints
源代码impl PartialEq for AVHWFramesConstraints
impl PartialEq for AVHWFramesConstraints
impl Copy for AVHWFramesConstraints
impl Eq for AVHWFramesConstraints
impl StructuralPartialEq for AVHWFramesConstraints
自动 trait 实现
impl Freeze for AVHWFramesConstraints
impl RefUnwindSafe for AVHWFramesConstraints
impl !Send for AVHWFramesConstraints
impl !Sync for AVHWFramesConstraints
impl Unpin for AVHWFramesConstraints
impl UnsafeUnpin for AVHWFramesConstraints
impl UnwindSafe for AVHWFramesConstraints
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多