#[repr(C)]pub struct AVMotionVector {
pub source: i32,
pub w: u8,
pub h: u8,
pub src_x: i16,
pub src_y: i16,
pub dst_x: i16,
pub dst_y: i16,
pub flags: u64,
pub motion_x: i32,
pub motion_y: i32,
pub motion_scale: u16,
}Fields
source: i32Where the current macroblock comes from; negative value when it comes from the past, positive value when it comes from the future. XXX: set exact relative ref frame reference instead of a +/- 1 “direction”.
w: u8Width and height of the block.
h: u8Width and height of the block.
src_x: i16Absolute source position. Can be outside the frame area.
src_y: i16Absolute source position. Can be outside the frame area.
dst_x: i16Absolute destination position. Can be outside the frame area.
dst_y: i16Absolute destination position. Can be outside the frame area.
flags: u64Extra flag information. Currently unused.
motion_x: i32Motion vector src_x = dst_x + motion_x / motion_scale src_y = dst_y + motion_y / motion_scale
motion_y: i32Motion vector src_x = dst_x + motion_x / motion_scale src_y = dst_y + motion_y / motion_scale
motion_scale: u16trait 实现
源代码impl Clone for AVMotionVector
impl Clone for AVMotionVector
源代码fn clone(&self) -> AVMotionVector
fn clone(&self) -> AVMotionVector
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVMotionVector
impl Debug for AVMotionVector
源代码impl PartialEq for AVMotionVector
impl PartialEq for AVMotionVector
impl Copy for AVMotionVector
impl Eq for AVMotionVector
impl StructuralPartialEq for AVMotionVector
自动 trait 实现
impl Freeze for AVMotionVector
impl RefUnwindSafe for AVMotionVector
impl Send for AVMotionVector
impl Sync for AVMotionVector
impl Unpin for AVMotionVector
impl UnsafeUnpin for AVMotionVector
impl UnwindSafe for AVMotionVector
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多