#[repr(C)]pub struct AVOption {
pub name: *const c_char,
pub help: *const c_char,
pub offset: c_int,
pub type_: AVOptionType,
pub default_val: AVOption__bindgen_ty_1,
pub min: f64,
pub max: f64,
pub flags: c_int,
pub unit: *const c_char,
}展开描述
AVOption
Fields
name: *const c_charhelp: *const c_charshort English help text @todo What about other languages?
offset: c_intNative access only.
The offset relative to the context structure where the option value is stored. It should be 0 for named constants.
type_: AVOptionTypedefault_val: AVOption__bindgen_ty_1min: f64< minimum valid value for the option
max: f64< maximum valid value for the option
flags: c_intA combination of AV_OPT_FLAG_*.
unit: *const c_charThe logical unit to which the option belongs. Non-constant options and corresponding named constants share the same unit. May be NULL.
trait 实现
自动 trait 实现
impl Freeze for AVOption
impl RefUnwindSafe for AVOption
impl !Send for AVOption
impl !Sync for AVOption
impl Unpin for AVOption
impl UnsafeUnpin for AVOption
impl UnwindSafe for AVOption
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多