#[repr(C)]pub struct AVPacketSideData {
pub data: *mut u8,
pub size: usize,
pub type_: AVPacketSideDataType,
}展开描述
This structure stores auxiliary information for decoding, presenting, or otherwise processing the coded stream. It is typically exported by demuxers and encoders and can be fed to decoders and muxers either in a per packet basis, or as global side data (applying to the entire coded stream).
Global side data is handled as follows:
- During demuxing, it may be exported through @ref AVCodecParameters.coded_side_data “AVStream’s codec parameters”, which can then be passed as input to decoders through the @ref AVCodecContext.coded_side_data “decoder context’s side data”, for initialization.
- For muxing, it can be fed through @ref AVCodecParameters.coded_side_data “AVStream’s codec parameters”, typically the output of encoders through the @ref AVCodecContext.coded_side_data “encoder context’s side data”, for initialization.
Packet specific side data is handled as follows:
- During demuxing, it may be exported through @ref AVPacket.side_data “AVPacket’s side data”, which can then be passed as input to decoders.
- For muxing, it can be fed through @ref AVPacket.side_data “AVPacket’s side data”, typically the output of encoders.
Different modules may accept or export different types of side data depending on media type and codec. Refer to @ref AVPacketSideDataType for a list of defined types and where they may be found or used.
Fields
data: *mut u8size: usizetype_: AVPacketSideDataTypetrait 实现
源代码impl Clone for AVPacketSideData
impl Clone for AVPacketSideData
源代码fn clone(&self) -> AVPacketSideData
fn clone(&self) -> AVPacketSideData
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVPacketSideData
impl Debug for AVPacketSideData
源代码impl PartialEq for AVPacketSideData
impl PartialEq for AVPacketSideData
impl Copy for AVPacketSideData
impl Eq for AVPacketSideData
impl StructuralPartialEq for AVPacketSideData
自动 trait 实现
impl Freeze for AVPacketSideData
impl RefUnwindSafe for AVPacketSideData
impl !Send for AVPacketSideData
impl !Sync for AVPacketSideData
impl Unpin for AVPacketSideData
impl UnsafeUnpin for AVPacketSideData
impl UnwindSafe for AVPacketSideData
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多