跳到主要内容

AVStreamGroup

搜索

结构体 AVStreamGroup 

源代码
#[repr(C)]
pub struct AVStreamGroup { pub av_class: *const AVClass, pub priv_data: *mut c_void, pub index: c_uint, pub id: i64, pub type_: AVStreamGroupParamsType, pub params: AVStreamGroup__bindgen_ty_1, pub metadata: *mut AVDictionary, pub nb_streams: c_uint, pub streams: *mut *mut AVStream, pub disposition: c_int, }

Fields

av_class: *const AVClass

A class for @ref avoptions. Set by avformat_stream_group_create().

priv_data: *mut c_voidindex: c_uint

Group index in AVFormatContext.

id: i64

Group type-specific group ID.

decoding: set by libavformat encoding: may set by the user

type_: AVStreamGroupParamsType

Group type

decoding: set by libavformat on group creation encoding: set by avformat_stream_group_create()

params: AVStreamGroup__bindgen_ty_1metadata: *mut AVDictionary

Metadata that applies to the whole group.

  • demuxing: set by libavformat on group creation
  • muxing: may be set by the caller before avformat_write_header()

Freed by libavformat in avformat_free_context().

nb_streams: c_uint

Number of elements in AVStreamGroup.streams.

Set by avformat_stream_group_add_stream() must not be modified by any other code.

streams: *mut *mut AVStream

A list of streams in the group. New entries are created with avformat_stream_group_add_stream().

  • demuxing: entries are created by libavformat on group creation. If AVFMTCTX_NOHEADER is set in ctx_flags, then new entries may also appear in av_read_frame().
  • muxing: entries are created by the user before avformat_write_header().

Freed by libavformat in avformat_free_context().

disposition: c_int

Stream group disposition - a combination of AV_DISPOSITION_* flags. This field currently applies to all defined AVStreamGroupParamsType.

  • demuxing: set by libavformat when creating the group or in avformat_find_stream_info().
  • muxing: may be set by the caller before avformat_write_header().

trait 实现

源代码

impl Clone for AVStreamGroup

源代码

fn clone(&self) -> AVStreamGroup

Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码

fn clone_from(&mut self, source: &Self)

source 执行拷贝赋值。 阅读更多
源代码

impl Copy for AVStreamGroup

自动 trait 实现

blanket 实现

源代码

impl<T> Any for T
where T: 'static + ?Sized,

源代码

fn type_id(&self) -> TypeId

获取 selfTypeId阅读更多
源代码

impl<T> Borrow<T> for T
where T: ?Sized,

源代码

fn borrow(&self) -> &T

从拥有的值不可变地借用。 阅读更多
源代码

impl<T> BorrowMut<T> for T
where T: ?Sized,

源代码

fn borrow_mut(&mut self) -> &mut T

从拥有的值可变地借用。 阅读更多
源代码

impl<T> CloneToUninit for T
where T: Clone,

源代码

unsafe fn clone_to_uninit(&self, dest: *mut u8)

🔬This is a nightly-only experimental API. (clone_to_uninit)
self 执行拷贝赋值到 dest阅读更多
源代码

impl<T> From<T> for T

源代码

fn from(t: T) -> T

原样返回参数。

源代码

impl<T, U> Into<U> for T
where U: From<T>,

源代码

fn into(self) -> U

Calls U::from(self).

That is, this conversion is whatever the implementation of From<T> for U 实现选择执行的操作。

源代码

impl<T> ToOwned for T
where T: Clone,

源代码

type Owned = T

获取所有权后得到的类型。
源代码

fn to_owned(&self) -> T

通常通过克隆,从借用数据创建拥有的数据。 阅读更多
源代码

fn clone_into(&self, target: &mut T)

通常通过克隆,使用借用数据替换拥有的数据。 阅读更多
源代码

impl<T, U> TryFrom<U> for T
where U: Into<T>,

源代码

type Error = Infallible

转换出错时返回的类型。
源代码

fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>

执行该转换。
源代码

impl<T, U> TryInto<U> for T
where U: TryFrom<T>,

源代码

type Error = <U as TryFrom<T>>::Error

转换出错时返回的类型。
源代码

fn try_into(self) -> Result<U, <U as TryFrom<T>>::Error>

执行该转换。