pub unsafe extern "C" fn av_opt_get_chlayout(
obj: *mut c_void,
name: *const c_char,
search_flags: c_int,
layout: *mut AVChannelLayout,
) -> c_int展开描述
@param[out] layout The returned layout is a copy of the actual value and must be freed with av_channel_layout_uninit() by the caller