#[repr(C)]pub struct AVFilter {
pub name: *const c_char,
pub description: *const c_char,
pub inputs: *const AVFilterPad,
pub outputs: *const AVFilterPad,
pub priv_class: *const AVClass,
pub flags: c_int,
}展开描述
Filter definition. This defines the pads a filter contains, and all the callback functions used to interact with the filter.
Fields
name: *const c_charFilter name. Must be non-NULL and unique among filters.
description: *const c_charA description of the filter. May be NULL.
You should use the NULL_IF_CONFIG_SMALL() macro to define it.
inputs: *const AVFilterPadList of static inputs.
NULL if there are no (static) inputs. Instances of filters with AVFILTER_FLAG_DYNAMIC_INPUTS set may have more inputs than present in this list.
outputs: *const AVFilterPadList of static outputs.
NULL if there are no (static) outputs. Instances of filters with AVFILTER_FLAG_DYNAMIC_OUTPUTS set may have more outputs than present in this list.
priv_class: *const AVClassA class for the private data, used to declare filter private AVOptions. This field is NULL for filters that do not declare any options.
If this field is non-NULL, the first member of the filter private data must be a pointer to AVClass, which will be set by libavfilter generic code to this class.
flags: c_intA combination of AVFILTER_FLAG_*