#[repr(C)]pub struct AVInputFormat {
pub name: *const c_char,
pub long_name: *const c_char,
pub flags: c_int,
pub extensions: *const c_char,
pub codec_tag: *const *const AVCodecTag,
pub priv_class: *const AVClass,
pub mime_type: *const c_char,
}展开描述
@addtogroup lavf_decoding @{
Fields
name: *const c_charA comma separated list of short names for the format. New names may be appended with a minor bump.
long_name: *const c_charDescriptive name for the format, meant to be more human-readable than name. You should use the NULL_IF_CONFIG_SMALL() macro to define it.
flags: c_intCan use flags: AVFMT_NOFILE, AVFMT_NEEDNUMBER, AVFMT_SHOW_IDS, AVFMT_NOTIMESTAMPS, AVFMT_GENERIC_INDEX, AVFMT_TS_DISCONT, AVFMT_NOBINSEARCH, AVFMT_NOGENSEARCH, AVFMT_NO_BYTE_SEEK, AVFMT_SEEK_TO_PTS.
extensions: *const c_charIf extensions are defined, then no probe is done. You should usually not use extension format guessing because it is not reliable enough
codec_tag: *const *const AVCodecTagpriv_class: *const AVClass< AVClass for the private context
mime_type: *const c_charComma-separated list of mime types. It is used check for matching mime types while probing. @see av_probe_input_format2
trait 实现
源代码impl Clone for AVInputFormat
impl Clone for AVInputFormat
源代码fn clone(&self) -> AVInputFormat
fn clone(&self) -> AVInputFormat
Returns a duplicate of the value. 阅读更多
1.0.0 · 源代码fn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
从
source 执行拷贝赋值。 阅读更多源代码impl Debug for AVInputFormat
impl Debug for AVInputFormat
源代码impl PartialEq for AVInputFormat
impl PartialEq for AVInputFormat
impl Copy for AVInputFormat
impl Eq for AVInputFormat
impl StructuralPartialEq for AVInputFormat
自动 trait 实现
impl Freeze for AVInputFormat
impl RefUnwindSafe for AVInputFormat
impl !Send for AVInputFormat
impl !Sync for AVInputFormat
impl Unpin for AVInputFormat
impl UnsafeUnpin for AVInputFormat
impl UnwindSafe for AVInputFormat
blanket 实现
源代码impl<T> BorrowMut<T> for Twhere
T: ?Sized,
impl<T> BorrowMut<T> for Twhere
T: ?Sized,
源代码fn borrow_mut(&mut self) -> &mut T
fn borrow_mut(&mut self) -> &mut T
从拥有的值可变地借用。 阅读更多